#
# spec file for package mirrormagic
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mirrormagic
Version:        3.0.0
Release:        bp156.4.9
Summary:        Puzzle game where you steer a beam of light using mirrors
License:        GPL-2.0-only
Group:          Amusements/Games/Logic
URL:            https://www.artsoft.org/mirrormagic/
Source0:        https://www.artsoft.org/RELEASES/unix/%{name}/%{name}-%{version}.tar.gz
Source1:        %{name}-icons.tar
Source2:        %{name}.desktop
# PATCH-FIX-UPSTREAM -- Fix LTO multiple definitions linking issue
Patch0:         fix-multiple-definitions.patch
# PATCH-FIX-UPSTREAM -- bmwiedemann emailed author - will be merged
Patch1:         reproducible.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(sdl2)
Requires(pre):  group(games) user(games)

%description
This is a nice little game with color graphics and sound for your
Unix system with color X11. You need an 8-bit color display or better.
It will not work on black&white systems, and maybe not on gray scale
systems.

It was first released as "Mindbender" in the year 1989 on the Amiga
(with ports on other computer systems) and is in fact a clone of the
C64 game "Deflektor".

%prep
%setup -q -b 1
%patch0 -p1
%patch1 -p1
rm -rfv lib mirrormagic
find . -name "*.orig" -delete

%build
%make_build sdl2 \
    PROGBASE=%{name} \
    OPTIONS="%{optflags} -fPIE" \
    EXTRA_LDFLAGS="%{optflags} -pie" \
    RO_GAME_DIR=%{_datadir}/%{name} \
    RW_GAME_DIR=%{_localstatedir}/games/%{name}

%install
# install executable
install -Dm 0755 %{name} %{buildroot}%{_bindir}/%{name}

# install directories
mkdir -p %{buildroot}%{_datadir}/%{name}/{graphics,levels,music,sounds}
for d in graphics levels music sounds ; do
    cp -a $d %{buildroot}%{_datadir}/%{name}
done

# install icons
for i in 32 48 64 72 96 ; do
    install -Dm 0644 ../icons/%{name}_${i}x${i}.png \
            %{buildroot}/%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

# install Desktop file
install -Dm 0644 %{S:2} %{buildroot}%{_datadir}/applications/%{name}.desktop

install -Dm 755 -d %{buildroot}%{_localstatedir}/games/%{name}/scores

%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}

%files
%license COPYING
%doc ChangeLog CREDITS
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/%{name}
%attr(0775,games,games) %{_localstatedir}/games/%{name}

%changelog
* Sun Sep 25 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to better declare dependencies
  to avoid non-determinism from parallel builds
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.0.0
  * Build with SDL2
  * Integrated the classic Mirror Magic game engine into the game
    Rocks’n’Diamonds as a new custom game engine
  * Mirror Magic now also offers new features already known from
    R’n’D like scalable window size and fullscreen mode and
    solution tapes were added to the included level sets
    “Deflektor” and “Mindbender”.
- Add fix-multiple-definitions.patch
- Drop upstream fixed mirrormagic-2.0.2-src_tools.c.patch,
  mirrormagic-2.0.2-src_editor.c.patch,
  mirrormagic-2.0.2-src_events.c.patch,
  mirrormagic-2.0.2-src_files.c.patch,
  mirrormagic-2.0.2-src_libgame_sdl.c.patch,
  mirrormagic-2.0.2-src_libgame_sdl.h.patch,
  mirrormagic-2.0.2-src_libgame_gadgets.c.patch and
  mirrormagic-2.0.2-src_main.h.patch
* Mon May  8 2017 rpm@fthiessen.de
- Fixed user and group for Factory
* Thu Mar 30 2017 meissner@suse.com
- prerequire useradd and groupadd
* Sat Jun 20 2015 dimstar@opensuse.org
- Force GNU inline semantics, fixes build with GCC5.
* Thu Oct 23 2014 nemysis@gmx.ch
- Change descriptions for patches
* Wed Oct 22 2014 nemysis@gmx.ch
- Remove not needed #%%attr
* Wed Oct 22 2014 nemysis@gmx.ch
- Initial package creation
